@@ -3,7 +3,7 @@
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.6   update date: 2023-06-07
+# Version : 1.4.7   update date: 2023-06-20
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -58,7 +58,7 @@ PORTNO=9088
 
 DATADIR=${DATADIR:-/data/gbase}
 ### dbspace init size.
-DBS1GB=${DBS1GB:-y}
+DBS1GB=${DBS1GB:-n}
 ROOTSIZE=1024000
 PLOGSIZE=2048000
 LLOGSIZE=4096000
@@ -471,7 +471,7 @@ sed -i "s#^MULTIPROCESSOR.*#MULTIPROCESSOR 1#g" $CFGFILE
 sed -i "s#^AUTO_TUNE.*#AUTO_TUNE 0#g" $CFGFILE
 sed -i "/^AUTO_TUNE/a\AUTO_REPREPARE 1" $CFGFILE
 sed -i "s#^CLEANERS.*#CLEANERS 32#g" $CFGFILE
-sed -i "s#^STACKSIZE.*#STACKSIZE 512#g" $CFGFILE
+sed -i "s#^STACKSIZE.*#STACKSIZE 1024#g" $CFGFILE
 sed -i "s#^ALLOW_NEWLINE.*#ALLOW_NEWLINE 1#g" $CFGFILE
 sed -i "s#^DS_MAX_QUERIES.*#DS_MAX_QUERIES 5#g" $CFGFILE
 sed -i "s#^DS_TOTAL_MEMORY.*#DS_TOTAL_MEMORY 1024000#g" $CFGFILE
