@@ -2,8 +2,8 @@
 ##################################################################
 # Filename: CheckEnv.sh
 # Function: Check Environment for GBase 8s install.
-# Write by: liaojinqing@gbase.cn
-# Version : 1.4.0   update date: 2022-01-11
+# Write by: liaosnet@gbasedbt.com
+# Version : 1.4.7   update date: 2023-06-21
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -11,6 +11,12 @@ loginfo(){
   echo -e "[$(date +'%Y-%m-%d %H:%M:%S')] $*"
 }
 
+##### yum install 
+if [ -x /usr/bin/yum ]; then
+  loginfo "Try to execute yum install.."
+  yum -y install unzip tar java-1.8.0-openjdk glibc-devel ncurses-libs ncurses-compat-libs libnsl libaio
+fi
+
 ##### Tool Check
 TOOLS="tar timeout unzip"
 QPATH="/usr/bin /usr/sbin /bin /sbin"
